@@ -19,6 +19,7 @@ from dataquality.schemas.task_type import TaskType
 from dataquality.utils.helpers import galileo_disabled
 
 CLOUD_URL = "https://console.cloud.rungalileo.io"
+MINIMUM_API_VERSION = "0.4.0"
 
 
 class GalileoConfigVars(str, Enum):
@@ -113,23 +114,39 @@ def _check_dq_version() -> None:
     """Check that user is running valid version of DQ client
     Pings backend to check minimum DQ version requirements.
     """
-    r = requests.get(f"{os.environ[GalileoConfigVars.API_URL]}/{Route.healthcheck}/dq")
+    r = requests.get(f"{config.api_url}/{Route.healthcheck}/dq")
     if not r.ok:
         if r.status_code == 404:
             # We don't want to raise error if api doesn't have dq healthcheck yet
             return
         raise GalileoException(r.text) from None
 
-    min_version = r.json()["minimum_dq_version"]
-    if version.parse(dq_version) < version.parse(min_version):
+    dq_version_parsed = version.parse(dq_version)
+
+    min_dq_version = r.json()["minimum_dq_version"]
+    if dq_version_parsed < version.parse(min_dq_version):
         msg = (
             f"⚠️ You are running an old version of dataquality. Please upgrade to "
-            f"version {min_version} or higher (you are running {dq_version})."
+            f"version {min_dq_version} or higher (you are running {dq_version})."
             f"  `pip install dataquality --upgrade`"
         )
         # The user is running an incompatible DQ version, must upgrade
         raise GalileoException(msg)
 
+    # If user is running an old API with new incompatible DQ version,
+    # prompt them to downgrade
+    api_version = r.json()["api_version"]
+    if version.parse(api_version) < version.parse(MINIMUM_API_VERSION):
+        msg_version = (
+            f"{dq_version_parsed.major}.{dq_version_parsed.minor}"  # type: ignore
+        )
+        msg = (
+            "Your Galileo API version is out of date. Please downgrade dataquality to "
+            f'`pip install "dataquality<{msg_version}"` or contact your admin to '
+            "upgrade your Galileo account."
+        )
+        raise GalileoException(msg)
+
 
 def _check_console_url() -> None:
     """Checks for user setting of GALILEO_CONSOLE_URL instead of
