@@ -10,7 +10,6 @@ from typing import Any, Dict, Iterable, List, Optional, TypeVar, Union
 
 import numpy as np
 import pandas as pd
-import pyarrow as pa
 import vaex
 from vaex.dataframe import DataFrame
 
@@ -60,7 +59,7 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
 
     DATA_FOLDER_EXTENSION = {data_folder: "hdf5" for data_folder in DATA_FOLDERS}
 
-    def __init__(self, meta: MetasType = None) -> None:
+    def __init__(self, meta: Optional[MetasType] = None) -> None:
         super().__init__()
         self.meta: Dict = meta or {}
         self.log_export_progress = True
@@ -74,7 +73,9 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
         """
         return f"{self.write_output_dir}/{BaseGalileoDataLogger.INPUT_DATA_BASE}"
 
-    def input_data_file(self, input_num: int = None, split: str = None) -> str:
+    def input_data_file(
+        self, input_num: Optional[int] = None, split: Optional[str] = None
+    ) -> str:
         """Return the path to the input data file.
 
         Example:
@@ -266,7 +267,7 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
         # Characters are each 1 byte. If more bytes > max, it needs to be large_string
         text_bytes = df_copy["text"].str.len().sum()
         if text_bytes > self.STRING_MAX_SIZE_B:
-            df_copy["text"] = df_copy["text"].to_arrow().cast(pa.large_string())
+            df_copy["text"] = df_copy['astype(text, "large_string")']
         return df_copy
 
     @classmethod
@@ -359,7 +360,8 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
 
         # Post concat, string columns come back as bytes and need conversion
         for col in str_cols:
-            out_frame[col] = out_frame[col].to_arrow().cast(pa.large_string())
+            out_frame[col] = out_frame[col].as_arrow().astype("str")
+            out_frame[col] = out_frame[f'astype({col}, "large_string")']
         if prob_only:
             out_frame["split"] = vaex.vconstant(
                 split, length=len(out_frame), dtype="str"
@@ -422,6 +424,7 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
 
         name = "inf_name" if split == Split.inference else "epoch"
         desc = f"{split} ({name}={epoch_inf})"
+
         for data_folder, df_obj in tqdm(
             zip(DATA_FOLDERS, [emb, prob, data_df]),
             total=3,
@@ -431,15 +434,24 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
         ):
             if df_obj.variables.get(DFVar.skip_upload):
                 continue
-
             ext = cls.DATA_FOLDER_EXTENSION[data_folder]
             minio_file = (
                 f"{proj_run}/{split}/{epoch_or_inf}/{data_folder}/{data_folder}.{ext}"
             )
+            cls._handle_numpy_floats(df=df_obj)
             object_store.create_project_run_object_from_df(
                 df=df_obj, object_name=minio_file
             )
 
+    @classmethod
+    def _handle_numpy_floats(cls, df: DataFrame) -> None:
+        """Validate that the provided embeddings, logits, and probabilities are
+        all float32s. This is done because vaex does not support float16."""
+        if "emb" in df.get_column_names() and df.emb.dtype == "float16":
+            df.emb = df.emb.astype("float32")
+        if "prob" in df.get_column_names() and df.prob.dtype == "float16":
+            df.prob = df.prob.astype("float32")
+
     @classmethod
     def prob_only(
         cls, epochs: List[str], split: str, epoch_or_inf_name: Union[int, str]
@@ -548,7 +560,7 @@ class BaseGalileoDataLogger(BaseGalileoLogger):
     @classmethod
     @abstractmethod
     def separate_dataframe(
-        cls, df: DataFrame, prob_only: bool = False, split: str = None
+        cls, df: DataFrame, prob_only: bool = False, split: Optional[str] = None
     ) -> BaseLoggerDataFrames:
         ...
 
