@@ -1,8 +1,6 @@
-import os
 from typing import Any, Dict, List, Optional, Union
 
 import pandas as pd
-from PIL.Image import Image
 from vaex.dataframe import DataFrame
 
 from dataquality.exceptions import GalileoException
@@ -16,7 +14,6 @@ from dataquality.loggers.logger_config.image_classification import (
 )
 from dataquality.schemas.dataframe import BaseLoggerDataFrames
 from dataquality.schemas.split import Split
-from dataquality.utils.cv import _img_path_to_b64_str, _img_to_b64_str
 
 # smaller than ITER_CHUNK_SIZE from base_data_logger because very large chunks
 # containing image data often won't fit in memory
@@ -49,6 +46,48 @@ class ImageClassificationDataLogger(TextClassificationDataLogger):
             inference_name=inference_name,
         )
 
+    def log_image_dataset(
+        self,
+        dataset: DataSet,
+        *,
+        imgs_colname: Optional[str] = None,
+        imgs_location_colname: Optional[str] = None,
+        imgs_dir: Optional[str] = None,
+        batch_size: int = ITER_CHUNK_SIZE_IMAGES,
+        id: str = "id",
+        label: Union[str, int] = "label",
+        split: Optional[Split] = None,
+        meta: Optional[List[Union[str, int]]] = None,
+        column_map: Optional[Dict[str, str]] = None,
+    ) -> Any:
+        if imgs_colname is None and imgs_location_colname is None:
+            raise GalileoException(
+                "Must provide one of imgs_colname or imgs_location_colname."
+            )
+        column_map = column_map or {id: "id"}
+        if isinstance(dataset, pd.DataFrame):
+            dataset = dataset.rename(columns=column_map)
+        elif self.is_hf_dataset(dataset):
+            dataset = self._prepare_hf(
+                dataset,
+                imgs_colname=imgs_colname,
+                imgs_location_colname=imgs_location_colname,
+                id_=id,
+            )
+        else:
+            raise GalileoException(
+                f"Dataset must be one of pandas or HF, but got {type(dataset)}"
+            )
+        self.log_dataset(
+            dataset=dataset,
+            batch_size=batch_size,
+            text="text",
+            id=id,
+            label=label,
+            split=split,
+            meta=meta,
+        )
+
     def convert_large_string(self, df: DataFrame) -> DataFrame:
         """We override to avoid doing the computation to check if the text is over 2GB
 
@@ -59,34 +98,6 @@ class ImageClassificationDataLogger(TextClassificationDataLogger):
         df["text"] = df['astype(text, "large_string")']
         return df
 
-    def _prepare_pandas(
-        self,
-        dataset: pd.DataFrame,
-        imgs_location_colname: Optional[str],
-        imgs_colname: Optional[str],
-        imgs_dir: Optional[str],
-    ) -> pd.DataFrame:
-        imgs_dir = imgs_dir or ""
-
-        if imgs_location_colname is not None:
-            # image paths
-            dataset["text"] = dataset[imgs_location_colname].apply(
-                lambda x: _img_path_to_b64_str(img_path=os.path.join(imgs_dir, x))
-            )
-        else:
-            # PIL images in a DataFrame column - weird, but we'll allow it
-            example = dataset[imgs_location_colname].values[0]
-            if not isinstance(example, Image):
-                raise GalileoException(
-                    f"Got imgs_colname={repr(imgs_colname)}, but that "
-                    "dataset column does not contain images. If you have "
-                    "image paths, pass imgs_location_colname instead."
-                )
-
-            dataset["text"] = dataset[imgs_colname].apply(_img_to_b64_str)
-
-        return dataset
-
     def _prepare_hf(
         self,
         dataset: DataSet,
@@ -120,6 +131,7 @@ class ImageClassificationDataLogger(TextClassificationDataLogger):
             raise GalileoException(
                 "Must provide one of imgs_colname or imgs_location_colname."
             )
+
         return prepared
 
     @classmethod
@@ -164,19 +176,27 @@ class ImageClassificationDataLogger(TextClassificationDataLogger):
         """
         validate_unique_ids(out_frame, epoch_or_inf_name)
 
-        emb_df = out_frame[["id", "emb"]]
+        emb_cols = ["id"] if prob_only else ["id", "emb"]
+        emb_df = out_frame[emb_cols]
         # The in_frame has gold, so we join with the out_frame to get the probabilities
         prob_df = out_frame.join(in_frame[["id", "gold"]], on="id")[
             cls._get_prob_cols()
         ]
-        remove_cols = emb_df.get_column_names() + prob_df.get_column_names()
 
-        # The data df needs pred, which is in the prob_df, so we join just on that col
-        # TODO: We should update runner processing so it can grab the pred from the
-        #  prob_df on the server. This is confusing code
-        data_cols = in_frame.get_column_names() + ["pred"]
-        data_cols = ["id"] + [c for c in data_cols if c not in remove_cols]
-        data_df = in_frame.join(out_frame[["id", "pred"]], on="id")[data_cols]
+        if prob_only:
+            emb_df = out_frame[["id"]]
+            data_df = out_frame[["id"]]
+        else:
+            emb_df = out_frame[["id", "emb"]]
+            remove_cols = emb_df.get_column_names() + prob_df.get_column_names()
+
+            # The data df needs pred, which is in the prob_df, so we join just on that
+            # col
+            # TODO: We should update runner processing so it can grab the pred from the
+            #  prob_df on the server. This is confusing code
+            data_cols = in_frame.get_column_names() + ["pred"]
+            data_cols = ["id"] + [c for c in data_cols if c not in remove_cols]
+            data_df = in_frame.join(out_frame[["id", "pred"]], on="id")[data_cols]
 
         dataframes = BaseLoggerDataFrames(prob=prob_df, emb=emb_df, data=data_df)
 
@@ -187,51 +207,3 @@ class ImageClassificationDataLogger(TextClassificationDataLogger):
         dataframes.prob.set_variable("progress_name", str(epoch_inf_val))
 
         return dataframes
-
-    def log_image_dataset(
-        self,
-        dataset: DataSet,
-        *,
-        imgs_colname: Optional[str] = None,
-        imgs_location_colname: Optional[str] = None,
-        imgs_dir: Optional[str] = None,
-        batch_size: int = ITER_CHUNK_SIZE_IMAGES,
-        id: str = "id",
-        label: Union[str, int] = "label",
-        split: Optional[Split] = None,
-        meta: Optional[List[Union[str, int]]] = None,
-        column_map: Optional[Dict[str, str]] = None,
-    ) -> Any:
-        if imgs_colname is None and imgs_location_colname is None:
-            raise GalileoException(
-                "Must provide one of imgs_colname or imgs_location_colname."
-            )
-        column_map = column_map or {id: "id"}
-        if isinstance(dataset, pd.DataFrame):
-            dataset = dataset.rename(columns=column_map)
-            dataset = self._prepare_pandas(
-                dataset,
-                imgs_colname=imgs_colname,
-                imgs_location_colname=imgs_location_colname,
-                imgs_dir=imgs_dir,
-            )
-        elif self.is_hf_dataset(dataset):
-            dataset = self._prepare_hf(
-                dataset,
-                imgs_colname=imgs_colname,
-                imgs_location_colname=imgs_location_colname,
-                id_=id,
-            )
-        else:
-            raise GalileoException(
-                f"Dataset must be one of pandas or HF, but got {type(dataset)}"
-            )
-        self.log_dataset(
-            dataset=dataset,
-            batch_size=batch_size,
-            text="text",
-            id=id,
-            label=label,
-            split=split,
-            meta=meta,
-        )
