@@ -63,9 +63,7 @@ def _join_in_out_frames(in_df: DataFrame, out_df: DataFrame) -> DataFrame:
     # https://github.com/vaexio/vaex/issues/1972
     in_frame["id"] = in_frame["id"].values
     out_frame = out_df.copy()
-    in_out = out_frame.join(
-        in_frame, on="id", how="inner", lsuffix="_L", rsuffix="_R"
-    ).copy()
+    in_out = out_frame.join(in_frame, on="id", how="inner", lsuffix="_L").copy()
     if len(in_out) != len(out_frame):
         num_missing = len(out_frame) - len(in_out)
         missing_ids = set(out_frame["id"].unique()) - set(in_out["id_L"].unique())
@@ -77,9 +75,6 @@ def _join_in_out_frames(in_df: DataFrame, out_df: DataFrame) -> DataFrame:
         )
     keep_cols = [c for c in in_out.get_column_names() if not c.endswith("_L")]
     in_out = in_out[keep_cols]
-    for c in in_out.get_column_names():
-        if c.endswith("_R"):
-            in_out.rename(c, c.rstrip("_R"))
     return in_out
 
 
