@@ -16,14 +16,16 @@ import dataquality.clients.api
 import dataquality.core._config
 import dataquality.core.finish
 from dataquality.exceptions import GalileoException, GalileoWarning, LogBatchError
+from dataquality.loggers import BaseGalileoLogger
 from dataquality.loggers.data_logger import BaseGalileoDataLogger
+from dataquality.loggers.model_logger import BaseGalileoModelLogger
 from dataquality.loggers.model_logger.text_classification import (
     TextClassificationModelLogger,
 )
 from dataquality.schemas.task_type import TaskType
 from dataquality.utils.thread_pool import ThreadPoolManager
 from tests.conftest import TEST_PATH
-from tests.utils.data_utils import (
+from tests.test_utils.data_utils import (
     NUM_LOGS,
     NUM_RECORDS,
     _log_text_classification_data,
@@ -258,8 +260,8 @@ def test_logging_inference_run(
         f"{TEST_PATH}/inference/last-week-customers/emb/emb.hdf5"
     )
 
-    assert (inference_emb_1.emb.to_numpy() == embs_1).all()
-    assert (inference_emb_2.emb.to_numpy() == embs_2).all()
+    assert np.isclose(inference_emb_1.emb.to_numpy(), embs_1).all()
+    assert np.isclose(inference_emb_2.emb.to_numpy(), embs_2).all()
 
     inference_prob_1 = vaex.open(f"{TEST_PATH}/inference/all-customers/prob/prob.hdf5")
     inference_prob_2 = vaex.open(
@@ -271,13 +273,13 @@ def test_logging_inference_run(
     assert "prob" in inference_prob_1.get_column_names()
     assert "prob" in inference_prob_2.get_column_names()
 
-    assert (
-        inference_prob_1.prob.to_numpy()
-        == dataquality.get_model_logger()().convert_logits_to_probs(logits_1)
+    assert np.isclose(
+        inference_prob_1.prob.to_numpy(),
+        dataquality.get_model_logger().convert_logits_to_probs(logits_1),
     ).all()
-    assert (
-        inference_prob_2.prob.to_numpy()
-        == dataquality.get_model_logger()().convert_logits_to_probs(logits_2)
+    assert np.isclose(
+        inference_prob_2.prob.to_numpy(),
+        dataquality.get_model_logger().convert_logits_to_probs(logits_2),
     ).all()
 
 
@@ -336,9 +338,9 @@ def test_logging_train_test_inference(
     test_emb_data = vaex.open(f"{TEST_PATH}/test/0/emb/emb.hdf5")
     inference_emb_data = vaex.open(f"{TEST_PATH}/inference/all-customers/emb/emb.hdf5")
 
-    assert (train_emb_data.emb.to_numpy() == train_embs).all()
-    assert (test_emb_data.emb.to_numpy() == test_embs).all()
-    assert (inference_emb_data.emb.to_numpy() == inf_embs).all()
+    assert np.isclose(train_emb_data.emb.to_numpy(), train_embs).all()
+    assert np.isclose(test_emb_data.emb.to_numpy(), test_embs).all()
+    assert np.isclose(inference_emb_data.emb.to_numpy(), inf_embs).all()
 
     train_prob_data = vaex.open(f"{TEST_PATH}/training/0/prob/prob.hdf5")
     test_prob_data = vaex.open(f"{TEST_PATH}/test/0/prob/prob.hdf5")
@@ -358,17 +360,17 @@ def test_logging_train_test_inference(
     assert "logits" not in test_prob_data.get_column_names()
     assert "logits" not in inference_prob_data.get_column_names()
 
-    assert (
-        train_prob_data.prob.to_numpy()
-        == dataquality.get_model_logger()().convert_logits_to_probs(train_logits)
+    assert np.isclose(
+        train_prob_data.prob.to_numpy(),
+        dataquality.get_model_logger().convert_logits_to_probs(train_logits),
     ).all()
-    assert (
-        test_prob_data.prob.to_numpy()
-        == dataquality.get_model_logger()().convert_logits_to_probs(test_logits)
+    assert np.isclose(
+        test_prob_data.prob.to_numpy(),
+        dataquality.get_model_logger().convert_logits_to_probs(test_logits),
     ).all()
-    assert (
-        inference_prob_data.prob.to_numpy()
-        == dataquality.get_model_logger()().convert_logits_to_probs(inf_logits)
+    assert np.isclose(
+        inference_prob_data.prob.to_numpy(),
+        dataquality.get_model_logger().convert_logits_to_probs(inf_logits),
     ).all()
 
 
@@ -616,7 +618,7 @@ def test_log_model_outputs_missing_embs_exclude_emb_false(
 
     with pytest.raises(AssertionError) as e:
         dataquality.log_model_outputs(**output_data)
-    assert str(e.value) == "embs can be None if and only if exclude_embs is True"
+    assert str(e.value) == "embs can be omitted if and only if exclude_embs is True"
 
 
 def test_log_model_outputs_with_embs_exclude_emb_true(
@@ -636,7 +638,7 @@ def test_log_model_outputs_with_embs_exclude_emb_true(
     with pytest.raises(AssertionError) as e:
         dataquality.log_model_outputs(**output_data)
 
-    assert str(e.value) == "embs can be None if and only if exclude_embs is True"
+    assert str(e.value) == "embs can be omitted if and only if exclude_embs is True"
 
 
 @mock.patch.object(
@@ -751,3 +753,37 @@ def test_cloud_restricts_inference_mode(mock_cloud: MagicMock) -> None:
         "accounts can access this feature. Please email us at team@rungalileo.io for "
         "more information."
     )
+
+
+def test_attribute_subsets() -> None:
+    """All potential logging fields used by all subclass loggers should be encapsulated
+
+    Any new logger that is created has a set of attributes that it expects from users.
+    The `BaseLoggerAttributes` from the BaseGalileoLogger should be the superset of
+    all child loggers.
+    """
+    all_attrs = set(BaseGalileoLogger.get_valid_attributes())
+    sub_data_loggers = BaseGalileoDataLogger.__subclasses__()
+    data_logger_attrs = set(
+        [j for i in sub_data_loggers for j in i.get_valid_attributes()]
+    )
+    sub_model_loggers = BaseGalileoModelLogger.__subclasses__()
+    model_logger_attrs = set(
+        [j for i in sub_model_loggers for j in i.get_valid_attributes()]
+    )
+    all_sub_attrs = data_logger_attrs.union(model_logger_attrs)
+    assert all_attrs.issuperset(
+        all_sub_attrs
+    ), f"Missing attrs: {all_sub_attrs - all_attrs}"
+
+
+def test_int_labels(set_test_config: Callable) -> None:
+    dataquality.set_labels_for_run(labels=[1, 2, 3, 4, 5])  # type: ignore
+    assert dataquality.get_data_logger().logger_config.labels == [
+        "1",
+        "2",
+        "3",
+        "4",
+        "5",
+    ]
+    assert dataquality.get_data_logger().logger_config.int_labels is True
